==> hoteldruid-mod-ru_3.0.4-1.tar.gz: ru/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":  		$messaggio = "Фамилия будет изменена с"; break;
case "a":  					$messaggio = "на"; break;
case "Il nome verrà cambiato da":  		$messaggio = "Имя будет изменено с"; break;
case "Continua":  				$messaggio = "Продолжить"; break;
case "Il cliente":  				$messaggio = "Клиент"; break;
case "è stato modificato":  			$messaggio = "был изменен"; break;
case "Torna indietro":  			$messaggio = "Назад"; break;
case "Modifica i dati del cliente":  		$messaggio = "Изменение данных клиента"; break;
case "Cognome":  				$messaggio = "Фамилия"; break;
case "cambia in":  				$messaggio = "изменить на"; break;
case "Nome":  					$messaggio = "Имя"; break;
case "cancella":  				$messaggio = "удалить"; break;
case "Sesso":  					$messaggio = "Пол"; break;
case "Data di nascita":  			$messaggio = "День рождения"; break;
case "Telefono":  				$messaggio = "Телефон"; break;
case "Via":  					$messaggio = "Улица"; break;
case "Piazza":  				$messaggio = "Площадь"; break;
case "Viale":  					$messaggio = "Проспект"; break;
case "Piazzale":  				$messaggio = "Бульвар"; break;
case "Vicolo":  				$messaggio = "Шоссе"; break;
case "Numero civico":  				$messaggio = "Номер дома"; break;
case "Città di residenza":  			$messaggio = "Город проживания"; break;
case "Nazione di residenza":  			$messaggio = "Страна проживания"; break;
case "CAP":  					$messaggio = "Почтовый индекс"; break;
case "Fax":  					$messaggio = "Факс"; break;
case "Email":  					$messaggio = "E-mail"; break;
case "2° telefono":  				$messaggio = "2-й телефон"; break;
case "3° telefono":  				$messaggio = "3-й телефон"; break;
case "Commento":  				$messaggio = "Комментарий"; break;
case "Prenotazioni del cliente":  		$messaggio = "Брони клиента"; break;
case "nel":  					$messaggio = "в"; break;
case "Cognome_del_cliente":  			$messaggio = "Фамилия_клиента"; break;
case "Data_iniziale":  				$messaggio = "Дата_начала"; break;
case "Data_finale":  				$messaggio = "Дата_окончания"; break;
case "Tariffa_completa":  			$messaggio = "Полная_цена"; break;
case "Caparra":  				$messaggio = "Депозит"; break;
case "Pagato":  				$messaggio = "Оплачен"; break;
case "Commento":  				$messaggio = "Комментарий"; break;
case "TOTALE":  				$messaggio = "ПОЛНЫЙ"; break;
case "Pers":  					$messaggio = "Люди"; break;
case "Inserito da":  				$messaggio = "Вставлено "; break;
case "come colui che ha inserito il cliente":	$messaggio = "будет считаться, что он добавил клиента"; break;
case "Cliente cancellato":  			$messaggio = "Клиент удален"; break;
case "Cancella il cliente":  			$messaggio = "Удалить клиента"; break;
case "NO":  					$messaggio = "НЕТ"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Вы уверены, что хотите <div style=\"display: inline; color: red;\">удалить</div> клиента"; break;
case "SI":  					$messaggio = "ДА"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Регион проживания"; break;
case "Documento":  				$messaggio = "Документ"; break;
case "Scadenza documento":  			$messaggio = "Дата действия документа"; break;
case "Cittadinanza":  				$messaggio = "Национальность"; break;
case "Nazione di nascita":  			$messaggio = "Страна рождения"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Регион рождения"; break;
case "Città di nascita":  			$messaggio = "Город рождения"; break;
case "Nazione di rilascio":  			$messaggio = "Страна выдачи"; break;
case "Codice fiscale":  			$messaggio = "Финансовый код"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "Modifica Cliente":  			$messaggio = "Modify Client"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "The gender will be changed to "; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "The birthdate will be changed from"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "The telephone will be changed from"; break;
case "La via  verrà cambiata da":  		$messaggio = "The street will be changed from"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "The street number will be changed from"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "The city of residence will be changed from"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "The nation of residence will be changed from"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "The postal code will be changed from"; break;
case "Il fax verrà cambiato da":  		$messaggio = "The fax will be changed from"; break;
case "L' email verrà cambiata da":  		$messaggio = "The email will be changed from"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "The 2nd telephone will be changed from"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "The 3rd telephone will be changed from"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "The <b>comment</b> will be changed"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "The <b>name</b> will be deleted"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "The <b>birthdate</b> will be deleted"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = "The <b>telephone</b> will be deleted"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = "The <b>street</b> will be deleted"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = "The <b>street number</b> will be deleted"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "The <b>city of residence</b> will be deleted"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "The <b>nation of residence</b> will be deleted"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "The <b>postal code</b> will be deleted"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "The <b>fax</b> will be deleted"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "The <b>email</b> will be deleted"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "The <b>2nd telephone</b> will be deleted"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "The <b>3rd telephone</b> will be deleted"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "Si considererà l'utente":  		$messaggio = "User"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "This client can not be deleted because he is still associated to some reservations"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "The region of residence will be changed from"; break;
case "Il documento verrà cambiato da":  	$messaggio = "The document will be changed from"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "The document expiration date will be changed from"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = "The <b>region of residence</b> will be deleted"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "The <b>document</b> will be deleted"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "The <b>document expiration date</b> will be deleted"; break;
case "Città di rilascio":  			$messaggio = "Releasing city"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Releasing region"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "The nationality will be changed from"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "The nation of birth will be changed from"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "The region of birth will be changed from"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "The city of birth will be changed from"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "The city releasing the document will be changed from"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "The region releasing the document will be changed from"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "The nation releasing the document will be changed from"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "The <b>nationality</b> will be deleted"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "The <b>nation of birth</b> will be deleted"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "The <b>region of birth</b> will be deleted"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "The <b>city of birth</b> will be deleted"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>city releasing the document</b> will be deleted"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>region releasing the document</b> will be deleted"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>nation releasing the document</b> will be deleted"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "The fiscal code will be changed from"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "The <b>fiscal code</b> will be deleted"; break;
case "Titolo":  				$messaggio = "Title"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "The title will be changed from"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "The <b>title</b> will be deleted"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "The VAT number will be changed from"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "The <b>VAT number</b> will be deleted"; break;
case "data inserimento":  			$messaggio = "insertion date"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "password to view credit cards"; break;
case "invia":  					$messaggio = "send"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "credit card data have been deleted"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "credit card number is <span class=\"colred\">wrong</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "CVC number is <span class=\"colred\">wrong</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "credit card data have been inserted"; break;
case "carta di credito del cliente":  		$messaggio = "credit card of client"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Scadenza":  				$messaggio = "Expiration"; break;
case "modifica i dati della carta di credito":	$messaggio = "modify credit card data"; break;
case "cancella questa carta di credito":  	$messaggio = "delete this credit card"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "The nickname will be changed from"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>nickname</b> will be deleted"; break;
case "Lingua":  				$messaggio = "Language"; break;
case "La lingua verrà cambiata da":  		$messaggio = "The language will be changed from"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "The <b>language</b> will be deleted"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "verrà modificato":  			$messaggio = "will be modified"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "scaduta":  				$messaggio = "expired"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "You'll be able to view credit cards again after changing the password"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "You'll be able to view credit cards again after the administrator user changes the password"; break;
case "Login temporaneamente bloccato":  	$messaggio = "Login temporarily locked"; break;
case "NOTA":  					$messaggio = "NOTICE"; break;
case "questo valore è gia stato cancellato, questa è l'ultima volta che viene visualizzato":	$messaggio = "this value has already been deleted, this is the last time you'll see it"; break;
case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "You'll be able to see this value only one more time"; break;
case "Cancellalo ora":  			$messaggio = "Delete it now"; break;
case "CVC cancellato":  			$messaggio = "CVC deleted"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
case "La seconda email verrà cambiata da":  	$messaggio = "The second email will be changed from"; break;
case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "The certified email will be changed from"; break;
case "La <b>seconda email</b> verrà cancellata":	$messaggio = "The <b>second email</b> will be deleted"; break;
case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "The <b>certified email</b> will be deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-ru_3.0.8-1.tar.gz: ru/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":  		$messaggio = "Фамилия будет изменена с"; break;
case "a":  					$messaggio = "на"; break;
case "Il nome verrà cambiato da":  		$messaggio = "Имя будет изменено с"; break;
case "Continua":  				$messaggio = "Продолжить"; break;
case "Il cliente":  				$messaggio = "Клиент"; break;
case "è stato modificato":  			$messaggio = "был изменен"; break;
case "Torna indietro":  			$messaggio = "Назад"; break;
case "Modifica i dati del cliente":  		$messaggio = "Изменение данных клиента"; break;
case "Cognome":  				$messaggio = "Фамилия"; break;
case "cambia in":  				$messaggio = "изменить на"; break;
case "Nome":  					$messaggio = "Имя"; break;
case "cancella":  				$messaggio = "удалить"; break;
case "Sesso":  					$messaggio = "Пол"; break;
case "Data di nascita":  			$messaggio = "День рождения"; break;
case "Telefono":  				$messaggio = "Телефон"; break;
case "Via":  					$messaggio = "Улица"; break;
case "Piazza":  				$messaggio = "Площадь"; break;
case "Viale":  					$messaggio = "Проспект"; break;
case "Piazzale":  				$messaggio = "Бульвар"; break;
case "Vicolo":  				$messaggio = "Шоссе"; break;
case "Numero civico":  				$messaggio = "Номер дома"; break;
case "Città di residenza":  			$messaggio = "Город проживания"; break;
case "Nazione di residenza":  			$messaggio = "Страна проживания"; break;
case "CAP":  					$messaggio = "Почтовый индекс"; break;
case "Fax":  					$messaggio = "Факс"; break;
case "Email":  					$messaggio = "E-mail"; break;
case "2° telefono":  				$messaggio = "2-й телефон"; break;
case "3° telefono":  				$messaggio = "3-й телефон"; break;
case "Commento":  				$messaggio = "Комментарий"; break;
case "Prenotazioni del cliente":  		$messaggio = "Брони клиента"; break;
case "nel":  					$messaggio = "в"; break;
case "Cognome_del_cliente":  			$messaggio = "Фамилия_клиента"; break;
case "Data_iniziale":  				$messaggio = "Дата_начала"; break;
case "Data_finale":  				$messaggio = "Дата_окончания"; break;
case "Tariffa_completa":  			$messaggio = "Полная_цена"; break;
case "Caparra":  				$messaggio = "Депозит"; break;
case "Pagato":  				$messaggio = "Оплачен"; break;
case "Commento":  				$messaggio = "Комментарий"; break;
case "TOTALE":  				$messaggio = "ПОЛНЫЙ"; break;
case "Pers":  					$messaggio = "Люди"; break;
case "Inserito da":  				$messaggio = "Вставлено "; break;
case "come colui che ha inserito il cliente":	$messaggio = "будет считаться, что он добавил клиента"; break;
case "Cliente cancellato":  			$messaggio = "Клиент удален"; break;
case "Cancella il cliente":  			$messaggio = "Удалить клиента"; break;
case "NO":  					$messaggio = "НЕТ"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Вы уверены, что хотите <div style=\"display: inline; color: red;\">удалить</div> клиента"; break;
case "SI":  					$messaggio = "ДА"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Регион проживания"; break;
case "Documento":  				$messaggio = "Документ"; break;
case "Scadenza documento":  			$messaggio = "Дата действия документа"; break;
case "Cittadinanza":  				$messaggio = "Национальность"; break;
case "Nazione di nascita":  			$messaggio = "Страна рождения"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Регион рождения"; break;
case "Città di nascita":  			$messaggio = "Город рождения"; break;
case "Nazione di rilascio":  			$messaggio = "Страна выдачи"; break;
case "Codice fiscale":  			$messaggio = "Финансовый код"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "Modifica Cliente":  			$messaggio = "Modify Client"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "The gender will be changed to "; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "The birthdate will be changed from"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "The telephone will be changed from"; break;
case "La via  verrà cambiata da":  		$messaggio = "The street will be changed from"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "The street number will be changed from"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "The city of residence will be changed from"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "The nation of residence will be changed from"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "The postal code will be changed from"; break;
case "Il fax verrà cambiato da":  		$messaggio = "The fax will be changed from"; break;
case "L' email verrà cambiata da":  		$messaggio = "The email will be changed from"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "The 2nd telephone will be changed from"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "The 3rd telephone will be changed from"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "The <b>comment</b> will be changed"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "The <b>name</b> will be deleted"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "The <b>birthdate</b> will be deleted"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = "The <b>telephone</b> will be deleted"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = "The <b>street</b> will be deleted"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = "The <b>street number</b> will be deleted"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "The <b>city of residence</b> will be deleted"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "The <b>nation of residence</b> will be deleted"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "The <b>postal code</b> will be deleted"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "The <b>fax</b> will be deleted"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "The <b>email</b> will be deleted"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "The <b>2nd telephone</b> will be deleted"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "The <b>3rd telephone</b> will be deleted"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "Si considererà l'utente":  		$messaggio = "User"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "This client can not be deleted because he is still associated to some reservations"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "The region of residence will be changed from"; break;
case "Il documento verrà cambiato da":  	$messaggio = "The document will be changed from"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "The document expiration date will be changed from"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = "The <b>region of residence</b> will be deleted"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "The <b>document</b> will be deleted"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "The <b>document expiration date</b> will be deleted"; break;
case "Città di rilascio":  			$messaggio = "Releasing city"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Releasing region"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "The nationality will be changed from"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "The nation of birth will be changed from"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "The region of birth will be changed from"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "The city of birth will be changed from"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "The city releasing the document will be changed from"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "The region releasing the document will be changed from"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "The nation releasing the document will be changed from"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "The <b>nationality</b> will be deleted"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "The <b>nation of birth</b> will be deleted"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "The <b>region of birth</b> will be deleted"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "The <b>city of birth</b> will be deleted"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>city releasing the document</b> will be deleted"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>region releasing the document</b> will be deleted"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>nation releasing the document</b> will be deleted"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "The fiscal code will be changed from"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "The <b>fiscal code</b> will be deleted"; break;
case "Titolo":  				$messaggio = "Title"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "The title will be changed from"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "The <b>title</b> will be deleted"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "The VAT number will be changed from"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "The <b>VAT number</b> will be deleted"; break;
case "data inserimento":  			$messaggio = "insertion date"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "password to view credit cards"; break;
case "invia":  					$messaggio = "send"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "credit card data have been deleted"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "credit card number is <span class=\"colred\">wrong</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "CVC number is <span class=\"colred\">wrong</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "credit card data have been inserted"; break;
case "carta di credito del cliente":  		$messaggio = "credit card of client"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Scadenza":  				$messaggio = "Expiration"; break;
case "modifica i dati della carta di credito":	$messaggio = "modify credit card data"; break;
case "cancella questa carta di credito":  	$messaggio = "delete this credit card"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "The nickname will be changed from"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>nickname</b> will be deleted"; break;
case "Lingua":  				$messaggio = "Language"; break;
case "La lingua verrà cambiata da":  		$messaggio = "The language will be changed from"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "The <b>language</b> will be deleted"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "verrà modificato":  			$messaggio = "will be modified"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "scaduta":  				$messaggio = "expired"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "You'll be able to view credit cards again after changing the password"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "You'll be able to view credit cards again after the administrator user changes the password"; break;
case "Login temporaneamente bloccato":  	$messaggio = "Login temporarily locked"; break;
case "NOTA":  					$messaggio = "NOTICE"; break;
case "questo valore è gia stato cancellato, questa è l'ultima volta che viene visualizzato":	$messaggio = "this value has already been deleted, this is the last time you'll see it"; break;
case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "You'll be able to see this value only one more time"; break;
case "Cancellalo ora":  			$messaggio = "Delete it now"; break;
case "CVC cancellato":  			$messaggio = "CVC deleted"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
case "La seconda email verrà cambiata da":  	$messaggio = "The second email will be changed from"; break;
case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "The certified email will be changed from"; break;
case "La <b>seconda email</b> verrà cancellata":	$messaggio = "The <b>second email</b> will be deleted"; break;
case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "The <b>certified email</b> will be deleted"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "Il 2° cognome verrà cambiato da":  	$messaggio = "The 2nd surname will be changed from"; break;
case "Il <b>2° cognome</b> verrà cancellato":	$messaggio = "The <b>2nd surname</b> will be deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
